#
# spec file for package oprofile (Version 0.9.4)
#
# Copyright (c) 2008 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           oprofile
BuildRequires:  binutils-devel java2-devel-packages libxslt popt-devel qt3-devel update-desktop-files
Url:            http://oprofile.sourceforge.net/
License:        GPL v2 or later
Group:          Development/Tools/Other
AutoReqProv:    on
PreReq:         /usr/sbin/groupadd /usr/sbin/useradd
Version:        0.9.4
Release:        48
Summary:        System-Wide Profiler for Linux Systems
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         %{name}-%{version}.tar.gz
Source1:        %{name}.desktop
Patch:          %{name}-%{version}.diff

%description
OProfile is a system-wide profiler for Linux systems, capable of
profiling all running code at low overhead. OProfile is released under
the GNU GPL.

It consists of a kernel module and a daemon for collecting sample data,
and several post-profiling tools for turning data into information.

OProfile leverages the CPU hardware performance counters to enable
profiling of a wide variety of interesting statistics, which can also
be used for basic time-spent profiling. All code is profiled: hardware
and software interrupt handlers, kernel modules, the kernel, shared
libraries, and applications (the only exception being the oprofile
interrupt handler itself).

OProfile is currently in alpha status; however it has proven stable
over a large number of differing configurations. As always, there is no
warranty.

This is the package containing the userspace tools.



Authors:
--------
    John Levon <moz@compsoc.man.ac.uk>
    Philippe Elie <phil_e@clubinternet.fr>
    Dave Jones <davej@suse.de>
    Bob Montgomery <bobm@fc.hp.com>

%package devel
Summary:        System-Wide Profiler for Linux Systems
Group:          Development/Libraries/C and C++
License:        GPL v2 or later; LGPL v2.1 or later
AutoReqProv:    on
Requires:       oprofile = %{version}-%{release} binutils-devel

%description devel
OProfile is a system-wide profiler for Linux systems, capable of
profiling all running code at low overhead. OProfile is released under
the GNU GPL.

It consists of a kernel module and a daemon for collecting sample data,
and several post-profiling tools for turning data into information.

OProfile leverages the CPU hardware performance counters to enable
profiling of a wide variety of interesting statistics, which can also
be used for basic time-spent profiling. All code is profiled: hardware
and software interrupt handlers, kernel modules, the kernel, shared
libraries, and applications (the only exception being the oprofile
interrupt handler itself).

OProfile is currently in alpha status; however it has proven stable
over a large number of differing configurations. As always, there is no
warranty.

This package contains the files needed to develop JIT agents for other
virtual machines.



Authors:
--------
    John Levon <moz@compsoc.man.ac.uk>
    Philippe Elie <phil_e@clubinternet.fr>
    Dave Jones <davej@suse.de>
    Bob Montgomery <bobm@fc.hp.com>

%prep
%setup -q
%patch

%build
autoreconf -fi
./configure CFLAGS="$RPM_OPT_FLAGS" CXXFLAGS="$RPM_OPT_FLAGS" \
	    --prefix=/usr --mandir=%{_mandir} --libdir=%{_libdir} \
	    --with-kernel-support --with-java=%_libdir/jvm/java \
	    --with-qt-libraries=%_libdir/qt3/%_lib
make %{?jobs:-j%jobs}

%install
make DESTDIR=$RPM_BUILD_ROOT htmldir=%{_docdir}/oprofile install
%suse_update_desktop_file -i %name Development Profiling

%pre
/usr/sbin/groupadd -r oprofile 2>/dev/null || :
/usr/sbin/useradd -r -g oprofile -d /var/lib/empty -s /bin/false -c "Special user account to be used by OProfile" oprofile 2>/dev/null || :

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
/usr/bin/*
/usr/share/applications/*.desktop
/usr/share/oprofile
%{_libdir}/*.so*
%exclude %{_libdir}/libopagent.so
%{_mandir}/man1/*
%doc doc/oprofile.html doc/internals.html doc/opreport.xsd
%doc COPYING README TODO ChangeLog 

%files devel
%defattr(-,root,root)
/usr/include/*
%doc doc/op-jit-devel.html 
%{_libdir}/*.*a
%{_libdir}/libopagent.so

%changelog
* Wed Oct 29 2008 schwab@suse.de
- Fix uninitialized variable.
* Thu Oct 23 2008 schwab@suse.de
- Ignore section symbols.
* Tue Oct 21 2008 schwab@suse.de
- Fix jvm agent libs.
* Fri Jul 18 2008 schwab@suse.de
- Update to oprofile 0.9.4.
  http://oprofile.sourceforge.net/release-notes/oprofile-0.9.4
* Fri Jul 11 2008 schwab@suse.de
- Update binutils check.
* Mon Nov 26 2007 schwab@suse.de
- Fix open call.
* Tue Oct 16 2007 schwab@suse.de
- Fix event mapping on 970MP [#333487].
* Thu Oct 11 2007 schwab@suse.de
- Fix missing includes.
* Tue Jul 17 2007 schwab@suse.de
- Update to oprofile 0.9.3.
* Wed Jul 04 2007 schwab@suse.de
- Update to oprofile 0.9.3-rc2.
* Mon Jun 18 2007 schwab@suse.de
- Update to oprofile 0.9.3-rc1.
* Thu Jan 11 2007 schwab@suse.de
- Add binutils-devel to BuildRequires.
* Mon Sep 18 2006 schwab@suse.de
- Update to oprofile 0.9.2 (no summary available).
* Fri Aug 18 2006 schwab@suse.de
- Avoid crash in find_nearest_line [#193622].
* Wed May 31 2006 schwab@suse.de
- Fix invalid string operation.
* Thu May 04 2006 schwab@suse.de
- Fix last change.
* Mon Feb 27 2006 schwab@suse.de
- Add events for Power5+ [#152494].
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 25 2006 schwab@suse.de
- Integrate fixes for ppc64 events and groups [#130910, #137665].
* Mon Dec 12 2005 schwab@suse.de
- Update to oprofile 0.9.1.
* Tue Nov 08 2005 dmueller@suse.de
- don't build as root
* Wed Sep 28 2005 schwab@suse.de
- Fix invalid C++.
* Wed Jul 06 2005 schwab@suse.de
- Unpack compressed vmlinux [#52767].
- Use RPM_OPT_FLAGS.
* Tue Jun 07 2005 schwab@suse.de
- Update to oprofile 0.9.
* Thu Mar 24 2005 schwab@suse.de
- Update to oprofile 0.8.2.
* Thu Nov 04 2004 schwab@suse.de
- Update to oprofile 0.8.1.
* Sat Sep 04 2004 schwab@suse.de
- Update to oprofile 0.8.
* Mon Jun 28 2004 skh@suse.de
- more fixes for #40468
  - fixed print statement in op_help.c
  - more power 4 events
  - fixed incorrect event counter settings for power 4
* Tue Jun 08 2004 skh@suse.de
- Update to fix for #40468: use correct event numbers for power5
  events.
* Wed May 26 2004 skh@suse.de
- Added default CYCLES event to the Power 4 and Power 5 event
  files. (#40468)
* Tue May 25 2004 skh@suse.de
- add user space support for ppc64 (#40468)
* Sun May 09 2004 ak@suse.de
- Increase minimum count on P4 to 5000 for all events
- Automatically add the module path of the current kernel to oprofpp
  (#36825)
- Fix 64bit uncleanness in symbol resolution (#36825)
* Sat Apr 10 2004 aj@suse.de
- Remove kernel-source requirement.
* Wed Feb 04 2004 skh@suse.de
- Updated to version 0.7.1
- Removed subpackage km_oprofile (it is part of the main kernel
  distribution as of kernel 2.6)
- Don't build as root.
* Mon Oct 06 2003 ak@suse.de
- Check if APIC is enabled instead of crashing (#31774)
  Needs updated kernel.
* Sat Aug 16 2003 adrian@suse.de
- add desktop file
* Thu Jul 31 2003 skh@suse.de
- Updated to 0.6
* Fri Jun 20 2003 mmj@suse.de
- Up to 0.5.4
* Fri Jun 13 2003 mmj@suse.de
- Package all dirs
* Wed Jun 04 2003 mmj@suse.de
- Make sure we get the right location for qt.
* Wed May 28 2003 mmj@suse.de
- Update to 0.5.3
* Tue May 13 2003 mmj@suse.de
- Use %%defattr
- Package forgotten files
* Mon Mar 31 2003 mmj@suse.de
- Update to 0.5.2 including:
   Docu overhaul
   Feature additions
- Bzip2'ed sources
- Folded both automake patches into one patch
* Tue Mar 11 2003 kukuk@suse.de
- Don't call depmod
* Tue Mar 11 2003 ro@suse.de
- remove k_deflt from neededforbuild (cycle)
* Mon Mar 10 2003 mmj@suse.de
- Fix typo
* Sat Mar 08 2003 mmj@suse.de
- A go at fixing km_oprofile
* Mon Mar 03 2003 duwe@suse.de
- split off km_oprofile
- tiny version update includes patches
* Mon Feb 24 2003 mmj@suse.de
- Add patch from davej to make it not crash the box
* Sat Feb 15 2003 adrian@suse.de
- minor dependency clean up
* Fri Feb 07 2003 mmj@suse.de
- Really fix build on x86_64
* Tue Feb 04 2003 mmj@suse.de
- Fix build on x86_64
* Tue Feb 04 2003 mmj@suse.de
- Update to oprofile 0.5:
   Pentium IV support, including support for HyperThreading, is
  supported for 2.5 kernels (currently only in the -mm patchset).
   Timer interrupt support for PA-RISC, ppc64, and sparc64 in 2.5
  kernels is available. Userspace Alpha support has been added.
   HyperThreading support for Pentium IV on 2.4 kernels is not yet
  available. Note that PA-RISC and Alpha require kernel patches
  not yet available in a released kernel tree.
   Support for the IA-64 architecture has been added for 2.4 kernels.
   OProfile's userspace now works correctly on all 64-bit platforms.
   A new script, opcontrol, has been added to unify control of the
  OProfile daemon and sample files. On 2.5, this allows separate
  daemon startup and starting/stopping profiling.
   Fixed upstream to compile with gcc 3.3
   Several bugfixes
* Wed Jan 29 2003 ro@suse.de
- fix build with gcc-3.3 (sluggish c++)
* Thu Nov 07 2002 mmj@suse.de
- Update to 0.4 which now has kernel 2.5 support
* Thu Sep 12 2002 mmj@suse.de
- Initial package, version 0.3 (x86 only for now)
